@@ -5,10 +5,8 @@ use strict;
 use warnings;
 
 use Carp ();
-use Data::Recursive::Encode;
-use Lingua::JA::Regular::Unicode qw/alnum_h2z space_h2z katakana_h2z/;
 
-our $VERSION = '0.31';
+our $VERSION = '0.40';
 
 require XSLoader;
 XSLoader::load(__PACKAGE__, $VERSION);
@@ -19,7 +17,6 @@ sub _options
     return {
         # analysis options
         model   => '/usr/local/share/kytea/model.bin',
-        h2z     => 1,
         nows    => 0,
         notags  => 0,
         notag   => [],
@@ -60,36 +57,6 @@ sub new
     return _init_text_kytea($class, $options);
 }
 
-sub _h2z { katakana_h2z( space_h2z( alnum_h2z($_[0]) ) ); }
-
-sub parse
-{
-    my ($self, $text) = @_;
-
-    my $is_h2z_enable = $self->_is_h2z_enable;
-
-    if ($is_h2z_enable)
-    {
-        my @original_chars = split(//, $text);
-        my $text = _h2z($text);
-
-        my $results = Data::Recursive::Encode->decode_utf8( $self->_parse($text) );
-
-        my $i = 0;
-
-        # changed char -> original char
-        for my $result (@{$results})
-        {
-            $result->{surface} = join( '', @original_chars[$i .. $i + (length $result->{surface}) - 1] );
-            $i += length $result->{surface};
-        }
-
-        return $results;
-    }
-
-    return Data::Recursive::Encode->decode_utf8( $self->_parse($text) );
-}
-
 1;
 __END__
 
@@ -105,7 +72,6 @@ my ($text, %config, $path);
 =head1 SYNOPSIS
 
   use Text::KyTea;
-  use utf8;
 
   my $kytea   = Text::KyTea->new(%config);
   my $results = $kytea->parse($text);
@@ -134,8 +100,8 @@ KyTea is a general toolkit developed for analyzing text,
 with a focus on Japanese, Chinese and other languages
 requiring word or morpheme segmentation.
 
-This module works under KyTea Ver.0.3.2 and later.
-Under the old versions of KyTea, this might not work.
+This module works under KyTea Ver.0.4.2 and later.
+Under the old versions of KyTea, this does not work!
 
 If you've changed the default install directory of KyTea,
 please install Text::KyTea with a interactive mode
@@ -146,15 +112,12 @@ For more information about KyTea, please see the "SEE ALSO" section of this page
 
 =head1 METHODS
 
-=over 4
-
-=item new(%config)
+=head2 new(%config)
 
 Creates a new Text::KyTea instance.
 
   my $kytea = Text::KyTea->new(
       model   => 'model.bin', # default is '/usr/local/share/kytea/model.bin'
-      h2z     => 0,           # default is 1 (enable)
       notag   => [1,2],       # default is []
       nounk   => 0,           # default is 0 (estimates the pronunciation of unkown words)
       unkbeam => 50,          # default is 50
@@ -164,13 +127,13 @@ Creates a new Text::KyTea instance.
   );
 
 
-=item new(h2z => 1)
+=head2 parse($text)
 
-Converts $text from hankaku to zenkaku before parsing $text.
-This option improves the parsing accuracy in most of model files.
+Parses the given text via KyTea, and returns the results of the analysis.
+The results are returned as an array reference.
 
 
-=item read_model($path)
+=head2 read_model($path)
 
 Reads the given model file.
 The model file should be read by new(model => $path) method.
@@ -178,21 +141,13 @@ The model file should be read by new(model => $path) method.
 Model files are available at http://www.phontron.com/kytea/model.html
 
 
-=item parse($text)
-
-Parses the given text via KyTea, and returns the results of the analysis.
-The results are returned as an array reference.
-
-
-=back
-
 =head1 AUTHOR
 
 pawa E<lt>pawapawa@cpan.orgE<gt>
 
 =head1 SEE ALSO
 
-http://www.phontron.com/kytea/
+L<http://www.phontron.com/kytea/>
 
 =head1 LICENSE
 
